==> eslint-config-basic-2.1.4.tgz: package/README.md <==
<div style="text-align: center;" align="center">

# @eslint-sets/eslint-config-basic

Eslint config basic sets

[![NPM version][npm-image]][npm-url]
[![Codacy Badge][codacy-image]][codacy-url]
[![Test coverage][codecov-image]][codecov-url]
[![npm download][download-image]][download-url]
[![gzip][gzip-image]][gzip-url]
[![License][license-image]][license-url]

[![Sonar][sonar-image]][sonar-url]

</div>

## Install

```bash
# use npm
$ npm install @eslint-sets/eslint-config-basic --save

# use yarn
$ yarn add @eslint-sets/eslint-config-basic

# use pnpm
$ pnpm install @eslint-sets/eslint-config-basic
```

## Usage

```js
// .eslintrc.js
module.exports = {
    extends: ['@eslint-sets/basic'],
    rules: {
        // custom rules
    }
}
```

## Issues & Support

Please open an issue [here](https://github.com/saqqdy/@eslint-sets/eslint-config-basic/issues).

## License

[MIT](LICENSE)

[npm-image]: https://img.shields.io/npm/v/@eslint-sets/eslint-config-basic.svg?style=flat-square
[npm-url]: https://npmjs.org/package/@eslint-sets/eslint-config-basic
[codacy-image]: https://app.codacy.com/project/badge/Grade/f70d4880e4ad4f40aa970eb9ee9d0696
[codacy-url]: https://www.codacy.com/gh/saqqdy/@eslint-sets/eslint-config-basic/dashboard?utm_source=github.com&utm_medium=referral&utm_content=saqqdy/@eslint-sets/eslint-config-basic&utm_campaign=Badge_Grade
[codecov-image]: https://img.shields.io/codecov/c/github/saqqdy/@eslint-sets/eslint-config-basic.svg?style=flat-square
[codecov-url]: https://codecov.io/github/saqqdy/@eslint-sets/eslint-config-basic?branch=master
[download-image]: https://img.shields.io/npm/dm/@eslint-sets/eslint-config-basic.svg?style=flat-square
[download-url]: https://npmjs.org/package/@eslint-sets/eslint-config-basic
[gzip-image]: http://img.badgesize.io/https://unpkg.com/@eslint-sets/eslint-config-basic/index.js?compression=gzip&label=gzip%20size:%20JS
[gzip-url]: http://img.badgesize.io/https://unpkg.com/@eslint-sets/eslint-config-basic/index.js?compression=gzip&label=gzip%20size:%20JS
[license-image]: https://img.shields.io/badge/License-MIT-blue.svg
[license-url]: LICENSE
[sonar-image]: https://sonarcloud.io/api/project_badges/quality_gate?project=saqqdy_eslint-sets
[sonar-url]: https://sonarcloud.io/dashboard?id=saqqdy_eslint-sets

==> eslint-config-basic-3.0.1.tgz: package/README.md <==
<div style="text-align: center;" align="center">

# @eslint-sets/eslint-config-basic

Eslint config basic sets

[![NPM version][npm-image]][npm-url]
[![Codacy Badge][codacy-image]][codacy-url]
[![Test coverage][codecov-image]][codecov-url]
[![npm download][download-image]][download-url]
[![gzip][gzip-image]][gzip-url]
[![License][license-image]][license-url]

[![Sonar][sonar-image]][sonar-url]

</div>

## Install

```bash
# use npm
$ npm install -D @eslint-sets/eslint-config-basic

# use yarn
$ yarn add -D @eslint-sets/eslint-config-basic

# use pnpm
$ pnpm install -D @eslint-sets/eslint-config-basic
```

## Usage

```js
// .eslintrc.js
module.exports = {
    extends: ['@eslint-sets/basic'],
    rules: {
        // custom rules
    }
}
```

## Issues & Support

Please open an issue [here](https://github.com/saqqdy/@eslint-sets/eslint-config-basic/issues).

## License

[MIT](LICENSE)

[npm-image]: https://img.shields.io/npm/v/@eslint-sets/eslint-config-basic.svg?style=flat-square
[npm-url]: https://npmjs.org/package/@eslint-sets/eslint-config-basic
[codacy-image]: https://app.codacy.com/project/badge/Grade/f70d4880e4ad4f40aa970eb9ee9d0696
[codacy-url]: https://www.codacy.com/gh/saqqdy/@eslint-sets/eslint-config-basic/dashboard?utm_source=github.com&utm_medium=referral&utm_content=saqqdy/@eslint-sets/eslint-config-basic&utm_campaign=Badge_Grade
[codecov-image]: https://img.shields.io/codecov/c/github/saqqdy/@eslint-sets/eslint-config-basic.svg?style=flat-square
[codecov-url]: https://codecov.io/github/saqqdy/@eslint-sets/eslint-config-basic?branch=master
[download-image]: https://img.shields.io/npm/dm/@eslint-sets/eslint-config-basic.svg?style=flat-square
[download-url]: https://npmjs.org/package/@eslint-sets/eslint-config-basic
[gzip-image]: http://img.badgesize.io/https://unpkg.com/@eslint-sets/eslint-config-basic/index.js?compression=gzip&label=gzip%20size:%20JS
[gzip-url]: http://img.badgesize.io/https://unpkg.com/@eslint-sets/eslint-config-basic/index.js?compression=gzip&label=gzip%20size:%20JS
[license-image]: https://img.shields.io/badge/License-MIT-blue.svg
[license-url]: LICENSE
[sonar-image]: https://sonarcloud.io/api/project_badges/quality_gate?project=saqqdy_eslint-sets
[sonar-url]: https://sonarcloud.io/dashboard?id=saqqdy_eslint-sets
